This is a fork of of serde_yaml2 that focuses on supporting serializing/deserialization from the intermediary parsed yaml representation, rather than from the raw string data.
In effect, this reduces the debugability of ser/de functionality from reading string data, but allows more direct manipulation of the source/resultant yaml.